Learn R Programming

EPGLM (version 1.1.2)

EPGLM-package: The package computes a Gaussian approximation of a Bayesian probit/logit using expectation propagation (EP).

Description

The package computes a Gaussian approximation of a Bayesian probit/logit using expectation propagation (EP). For the moment the only available prior is a Gaussian. The algorithm is based on the observation of Chopin and Ridgway [2015].

Arguments

Details

Package:
EPGLM
Type:
Package
Version:
1.0
Date:
2016-08-23
License:
GPL (>= 2)

References

N. Chopin and J. Ridgway. Leave Pima Indians alone: binary regression as a benchmark for Bayesian computation. arxiv preprint